
Django admin app
* uses django-suit app
* automatically installs admin

Installation:
* install djrunner app
* add `cap` to `INSTALLED_APPS`
* add `ADMIN_MENU` setting instead of `SuitConfig.menu`
* add `SITE_HEADER` setting to set admin title
